aboutsummaryrefslogtreecommitdiff
path: root/openembedded-lkft
diff options
context:
space:
mode:
authorFathi Boudra <fathi.boudra@linaro.org>2017-06-27 15:57:09 +0300
committerFathi Boudra <fathi.boudra@linaro.org>2017-06-30 10:34:59 +0300
commit035cd2fb1c3f58ec20c7b39c38a79fcd906471ca (patch)
treedb4acfcbb7346312812c73a7dcc7b08fc513ef2d /openembedded-lkft
parent5549d141480e59a05006391404d4146146664b2a (diff)
openembedded-lkft: remove docker from the images
It makes sense to ship docker in RPB context but not for LKFT. While LKFT images are based on RPB, we don't want to ship docker to reduce the images size. Change-Id: I1e58fa22e58300a4a9cd5f7e5ef987cc4863e5c6 Signed-off-by: Fathi Boudra <fathi.boudra@linaro.org>
Diffstat (limited to 'openembedded-lkft')
-rwxr-xr-xopenembedded-lkft/builders.sh5
1 files changed, 4 insertions, 1 deletions
diff --git a/openembedded-lkft/builders.sh b/openembedded-lkft/builders.sh
index 38f8827121..d7f2cfe445 100755
--- a/openembedded-lkft/builders.sh
+++ b/openembedded-lkft/builders.sh
@@ -97,9 +97,12 @@ cat << EOF >> conf/local.conf
CMDLINE_remove = "quiet"
EOF
# Remove 96boards-tools to avoid resizing on first boot
cat << EOF >> conf/local.conf
RDEPENDS_packagegroup-rpb_remove = "96boards-tools"
+RDEPENDS_packagegroup-rpb_remove = "docker"
EOF
# Remove systemd firstboot and machine-id file
@@ -97,9 +97,12 @@ cat << EOF >> conf/local.conf
CMDLINE_remove = "quiet"
EOF
-# Remove 96boards-tools to avoid resizing on first boot
+# Remove recipes:
+# - 96boards-tools to avoid resizing on first boot
+# - docker to reduce image size
cat << EOF >> conf/local.conf
RDEPENDS_packagegroup-rpb_remove = "96boards-tools"